# DT CLIMATE - ENERGY OFFSHORE USE CASE

This package uses the Destination Earth: Digital Twin of Climate simulations
to produce a set of statistics in support of offshore wind
farm siting and long term operations. Please see the [use case homepage](https://earth.bsc.es/gitlab/digital-twins/de_340/energy_offshore) for more details.